Enyo is a lightweight multistage partition based encryption algorithm

# Description
    
It consists of two main modules:

- `enyoencryption`: Enyo Encryption algorithm module
- `enyodecryption`: Enyo Decryption algorithm module

# Installation
 
## Normal installation

```bash
pip install enyo
```

## Development installation

```bash
git clone https://github.com/apratimshukla6/enyo.git
cd enyo
pip install --editable .
```